@@ -6,7 +6,7 @@ import json
 import requests
 
 from .logging import log
-from . import upload, inference
+# from . import inference
 
 
 def get(worker_id):
@@ -51,31 +51,38 @@ def get(worker_id):
     return None
 
 
-def run(job):
+def run(job, run_handler):
     '''
     Run the job.
     Returns list of URLs and Job Time
     '''
     time_job_started = time.time()
-
     log(f"Started working on {job['id']} at {time_job_started} UTC")
 
-    model = inference.Model()
+    # model = inference.Model()
 
-    job_output = model.run(job)
+    # job_output = model.run(job)
+    job_output = run_handler(job)
 
-    if "error" in job_output:
-        return {
-            "error": job_output["error"]
-        }
+    log(f"Job output: {job_output}")
 
-    if "images" in job_output:
-        object_urls = upload.upload_image(job['id'], job_output["images"])
-        job_output["images"] = object_urls
+    for index, output in enumerate(job_output):
+        log(f"Output {index}: {output}")
+
+        if "error" in output:
+            return {
+                "error": output["error"]
+            }
+
+        # if "image" in output:
+        #     object_url = upload.upload_image(job['id'], output["image"], index)
+        #     output["image"] = object_url
 
     job_duration = time.time() - time_job_started
     job_duration_ms = int(job_duration * 1000)
 
+    log(f"Returning as output: {job_output}")
+
     return {
         "output": job_output,
         "duration_ms": job_duration_ms
@@ -86,15 +93,16 @@ def post(worker_id, job_id, job_output, job_time):
     '''
     Complete the job.
     '''
-    if os.environ.get('RUNPOD_WEBHOOK_POST_OUTPUT', None) is None:
-        return
-
     job_data = {
         "output": job_output
     }
 
     job_data = json.dumps(job_data, ensure_ascii=False)
 
+    if os.environ.get('RUNPOD_WEBHOOK_POST_OUTPUT', None) is None:
+        log("RUNPOD_WEBHOOK_POST_OUTPUT not set, skipping completing job", 'WARNING')
+        return
+
     job_done_url = str(os.environ.get('RUNPOD_WEBHOOK_POST_OUTPUT'))
     job_done_url = job_done_url.replace('$ID', job_id)
     job_done_url = job_done_url.replace('$RUNPOD_POD_ID', worker_id)
